@@ -20,10 +20,7 @@
 #include <config.h>
 #include "gconf-cell-renderer.h"
 
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtkcellrenderertoggle.h>
-#include <gtk/gtkentry.h>
-#include <gtk/gtksignal.h>
+#include <gtk/gtk.h>
 #include <glib/gi18n.h>
 
 #include "gconf-util.h"
@@ -460,12 +457,10 @@ gconf_cell_renderer_init (GConfCellRenderer *renderer)
 	GTK_CELL_RENDERER (renderer)->mode = GTK_CELL_RENDERER_MODE_ACTIVATABLE;
 	
 	renderer->text_renderer = gtk_cell_renderer_text_new ();
-	g_object_ref (renderer->text_renderer);
-	gtk_object_sink (GTK_OBJECT (renderer->text_renderer));
+	g_object_ref_sink (renderer->text_renderer);
 
 	renderer->toggle_renderer = gtk_cell_renderer_toggle_new ();
-	g_object_ref (renderer->toggle_renderer);
-	gtk_object_sink (GTK_OBJECT (renderer->toggle_renderer));
+	g_object_ref_sink (renderer->toggle_renderer);
 }
 
 
