@@ -25,28 +25,10 @@
 #include "gconf-cell-renderer.h"
 #include "gconf-key-editor.h"
 
-#include <gtk/gtkalignment.h>
-#include <gtk/gtkcellrenderer.h>
-#include <gtk/gtkentry.h>
-#include <gtk/gtkframe.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkcombobox.h>
-#include <gtk/gtkscrolledwindow.h>
-#include <gtk/gtksizegroup.h>
-#include <gtk/gtkspinbutton.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtktogglebutton.h>
-#include <gtk/gtktreeselection.h>
-#include <gtk/gtktreeview.h>
-#include <gtk/gtkvbox.h>
-#include <gtk/gtkvbbox.h>
-#include <libintl.h>
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
 #include <string.h>
 
-#define _(x) gettext (x)
-
 enum
 {
   EDIT_INTEGER,
@@ -143,6 +125,9 @@ gconf_key_editor_create_combo_box (GConfKeyEditor *editor)
 	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("Integer"));
 	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("Boolean"));
 	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("String"));
+	/* Translators: this refers to "Floating point":
+	 * see http://en.wikipedia.org/wiki/Floating_point
+	 */
 	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("Float"));
 	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("List"));
 
@@ -585,7 +570,7 @@ gconf_key_editor_init (GConfKeyEditor *editor)
 	gtk_size_group_add_widget (size_group, label);
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 	editor->name_entry = gtk_entry_new ();
-	gtk_widget_set_usize (editor->name_entry, 250, -1);
+	gtk_widget_set_size_request (editor->name_entry, 250, -1);
 	gtk_entry_set_activates_default (GTK_ENTRY (editor->name_entry), TRUE);
 	gtk_box_pack_start (GTK_BOX (hbox), editor->name_entry, TRUE, TRUE, 0);
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), editor->name_entry);
@@ -605,6 +590,8 @@ gconf_key_editor_init (GConfKeyEditor *editor)
 	gtk_widget_show_all (hbox);
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
+	g_object_unref (size_group);
+
 	framebox = gtk_vbox_new (FALSE, 6);
 	gtk_widget_show (framebox);
 	gtk_box_pack_start (GTK_BOX (vbox), framebox, FALSE, FALSE, 0);
@@ -697,7 +684,6 @@ gconf_key_editor_init (GConfKeyEditor *editor)
 
         /* EDIT_LIST */
 	editor->list_box = gtk_hbox_new (FALSE, 0);
-	hbox = gtk_hbox_new (FALSE, 12);
 	label = gtk_label_new ("    ");
 	gtk_widget_show (label);
 	gtk_box_pack_start (GTK_BOX (editor->list_box), label, FALSE, FALSE, 0);
