@@ -20,16 +20,15 @@
 #ifndef __GCONF_KEY_EDITOR_H__
 #define __GCONF_KEY_EDITOR_H__
 
-#include <gtk/gtkdialog.h>
-#include <gtk/gtkliststore.h>
+#include <gtk/gtk.h>
 #include <gconf/gconf.h>
 
 #define GCONF_TYPE_KEY_EDITOR		  (gconf_key_editor_get_type ())
-#define GCONF_KEY_EDITOR(obj)		  (GTK_CHECK_CAST ((obj), GCONF_TYPE_KEY_EDITOR, GConfKeyEditor))
-#define GCONF_KEY_EDITOR_CLASS(klass)	  (GTK_CHECK_CLASS_CAST ((klass), GCONF_TYPE_KEY_EDITOR, GConfKeyEditorClass))
-#define GCONF_IS_KEY_EDITOR(obj)	  (GTK_CHECK_TYPE ((obj), GCONF_TYPE_KEY_EDITOR))
-#define GCONF_IS_KEY_EDITOR_CLASS(klass)  (GTK_CHECK_CLASS_TYPE ((obj), GCONF_TYPE_KEY_EDITOR))
-#define GCONF_KEY_EDITOR_GET_CLASS(obj)   (GTK_CHECK_GET_CLASS ((obj), GCONF_TYPE_KEY_EDITOR, GConfKeyEditorClass))
+#define GCONF_KEY_EDITOR(obj)		  (G_TYPE_CHECK_INSTANCE_CAST ((obj), GCONF_TYPE_KEY_EDITOR, GConfKeyEditor))
+#define GCONF_KEY_EDITOR_CLASS(klass)	  (G_TYPE_CHECK_CLASS_CAST ((klass), GCONF_TYPE_KEY_EDITOR, GConfKeyEditorClass))
+#define GCONF_IS_KEY_EDITOR(obj)	  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GCONF_TYPE_KEY_EDITOR))
+#define GCONF_IS_KEY_EDITOR_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((obj), GCONF_TYPE_KEY_EDITOR))
+#define GCONF_KEY_EDITOR_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), GCONF_TYPE_KEY_EDITOR, GConfKeyEditorClass))
 
 typedef enum {
 	GCONF_KEY_EDITOR_NEW_KEY,
